@@ -16,7 +16,8 @@ CROP_TYPE = {
     'm_bu': ['模特胸像正面', '模特胸像侧面', '模特胸像背面'],
     'm_bo': ['模特下身正面', '模特下身侧面', '模特下身背面'],
     'm_f': ['模特全身正面', '模特全身侧面', '模特全身背面'],
-    't': ['平铺图背面', '平铺图正面']
+    't': ['平铺图背面', '平铺图正面'],
+    'b': ['资质图', '吊牌图', '洗水唛']
 }
 
 
@@ -88,6 +89,10 @@ class Image:
         self.image_detail = ImageDetail()
         self.detail_point = {}  # {'裁剪模特帽子':{},}
 
+        if self.img_crop_type == 'b':
+            self.brand = Brand(image_analysis)
+            self.brand_crop_point = self.brand.deal_brand_crop_point()
+
         self.match_crop_detail = []
 
     def hand_hot_area_data(self, area_data):
@@ -816,6 +821,79 @@ class Cloths:
         garment['cat_name'] = one_garment['cat_name']  # 服装分类name
         return garment
 
+class Brand:
+    def __init__(self, image_analysis):
+        self.image_analysis = image_analysis
+        self.threshold = 0.6  # 小于0.6不可信
+        self.brand_list = self.ai_brand_info(image_analysis.get("recognition"))
+
+    def ai_brand_info(self, brand_json):
+        '''计算各个资质图的分类 及box '''
+
+        if not brand_json:
+            return []
+
+        brand_list = []
+        try:
+            brand_info = json.loads(brand_json)
+            self.image_width, self.image_height = brand_info['image']['width'], brand_info['image']['height']
+            for one_brand in brand_info['labels']:
+                if one_brand['confidence'] < self.threshold:  # 置信度过低
+                    continue
+                brand = self.deal_brand(one_brand)
+                brand_list.append(brand)
+        except Exception:
+            raise Exception(f"ai识别结果-资质图box-解析失败: {json.dumps(self.image_analysis)}")
+            # logging.error(f"ai识别结果-资质图box-解析失败: {json.dumps(self.image_analysis)} ", exc_info=True)
+        return brand_list
+
+    def deal_brand(self, one_brand):
+        '''处理下 每个资质图的 box cat_id cat_name confidence'''
+
+
+        brand = dict()
+
+        #  服装的区域
+        brand['box'] = [
+            one_brand['bbox'][0] / self.image_width,
+            one_brand['bbox'][1] / self.image_height,
+            one_brand['bbox'][2] / self.image_width,
+            one_brand['bbox'][3] / self.image_height
+        ]
+
+        brand['cat_id'] = one_brand['category_id']  # 服装分类id
+        brand['cat_name'] = one_brand['category']  # 资质图分类name
+        return brand
+
+    def deal_brand_crop_point(self):
+        brand_crop_point_dict = {}
+        for brand in self.brand_list:
+            brand_crop_point_dict = self.brand_crop_point(brand, brand_crop_point_dict)
+        return brand_crop_point_dict
+
+    def brand_crop_point(self, brand, crop_point_dict):
+        # 资质图上边:brand_top
+        # 资质图下边:brand_bottom
+
+        brand_box = brand['box']
+        if not crop_point_dict.get('brand_top'):
+            point = dict()
+            point['top_site'] = brand_box[0], brand_box[1]
+            point['bottom_site'] = brand_box[2], brand_box[3]
+            crop_point_dict['brand_top'] = crop_point_dict['brand_bottom'] = point
+            return crop_point_dict
+
+        brand_top_site = crop_point_dict['brand_top']['top_site']
+        brand_bottom_site = crop_point_dict['brand_bottom']['bottom_site']
+        # 取最小
+        crop_point_dict['brand_top']['top_site'] = min(brand_top_site[0], brand_box[0]), min(brand_top_site[1],
+                                                                                                 brand_box[1])
+        # 取最大
+        crop_point_dict['brand_top']['bottom_site'] = max(brand_bottom_site[0], brand_box[2]), max(
+            brand_bottom_site[1], brand_box[3])
+        crop_point_dict['brand_bottom'] = crop_point_dict['brand_top']
+        return crop_point_dict
+
 
 class ImageDetail:
     """
